============
Contributing
============

Thanks for your interest in contributing! The help is always appreciated.

`Uranium`<http://uranium.readthedocs.io/en/latest/> is used to simplify setup and task execution.

------------------
Submitting a Patch
------------------

If you have a more general idea, it may be good to start it as an
issue first. That gives a channel of feedback to hone or validate the
idea with the maintainers.

Patches should:

* pass the existing unit tests
* include unit tests for any modified behaviour

Commits may be squashed or modified, to fit into the commit style of
the repo.

------------------------
Building / Running Tests
------------------------

No local setup is necessary to run unit tests and work with the
project.

run the unit tests:

.. code-block::

    ./uranium test


-------------
Patch License
-------------

The patch should be licensed under the same license as the main
project (MIT).
